Structs
- Checker
Options - Compiler options for type checking.
- Compiler
Options - Parsed
TsConfig - Result of parsing a tsconfig.json with diagnostic collection.
- Path
Mapping - Resolved
Compiler Options - TsConfig
Enums
Functions
- checker_
target_ from_ emitter - Convert emitter
ScriptTargetto checkerScriptTarget. The emitter has more variants (ES2021,ES2022) which map toESNextin the checker. - core_
lib_ name_ for_ target - Get the core lib name for a target (without DOM/ScriptHost).
- default_
lib_ dir - Get the default lib directory.
- default_
lib_ name_ for_ target - Get the default lib name for a target.
- load_
tsconfig - load_
tsconfig_ with_ diagnostics - Load tsconfig.json and collect config-level diagnostics.
- parse_
tsconfig - parse_
tsconfig_ with_ diagnostics - Parse tsconfig.json source and collect diagnostics for unknown compiler options.
- resolve_
compiler_ options - resolve_
default_ lib_ files - Resolve default lib files for a given target.
- resolve_
default_ lib_ files_ from_ dir - resolve_
lib_ files - Resolve lib files from names, following
/// <reference lib="..." />directives. This is used when explicitly specifying libs via--lib. - resolve_
lib_ files_ from_ dir - resolve_
lib_ files_ from_ dir_ with_ options - resolve_
lib_ files_ with_ options - Resolve lib files from names, optionally following
/// <reference lib="..." />directives.