pub struct ParsedTsConfig {
pub config: TsConfig,
pub diagnostics: Vec<Diagnostic>,
pub suppress_excess_property_errors: bool,
pub suppress_implicit_any_index_errors: bool,
}Expand description
Result of parsing a tsconfig.json with diagnostic collection.
Fields
config: TsConfigdiagnostics: Vec<Diagnostic>suppress_excess_property_errors: boolCaptured from removed option suppressExcessPropertyErrors before stripping.
tsc still honors its effect even after removal (TS5102).
suppress_implicit_any_index_errors: boolCaptured from removed option suppressImplicitAnyIndexErrors before stripping.
tsc still honors its effect even after removal (TS5102).