pub struct LocaleMessages { /* private fields */ }Expand description
Container for locale-specific diagnostic messages.
Implementations
Sourceimpl LocaleMessages
impl LocaleMessages
Sourcepub fn load(locale_id: &str) -> Option<Self>
pub fn load(locale_id: &str) -> Option<Self>
Load a locale from the embedded locale files.
Returns None if the locale is not supported or fails to parse.
Sourcepub fn get_message<'a>(&self, code: u32, fallback: &'a str) -> &'a str
pub fn get_message<'a>(&self, code: u32, fallback: &'a str) -> &'a str
Get the translated message for a diagnostic code.
Returns the translated message if available, otherwise returns the fallback.
Sourcepub fn get_message_owned(&self, code: u32, fallback: &str) -> String
pub fn get_message_owned(&self, code: u32, fallback: &str) -> String
Get the translated message for a diagnostic code, returning an owned String.
Returns the translated message if available, otherwise returns the fallback.
Sourcepub fn has_translation(&self, code: u32) -> bool
pub fn has_translation(&self, code: u32) -> bool
Check if this locale has a translation for the given code.
Sourcepub const fn is_default(&self) -> bool
pub const fn is_default(&self) -> bool
Returns true if this is the default (English) locale.