pub fn get_declaration_output_path(
project: &ResolvedProject,
source_file: &Path,
) -> Option<PathBuf>Expand description
Get the declaration output path for a source file in a composite project
pub fn get_declaration_output_path(
project: &ResolvedProject,
source_file: &Path,
) -> Option<PathBuf>Get the declaration output path for a source file in a composite project