pub struct CompilerOptions {Show 61 fields
pub target: Option<String>,
pub module: Option<String>,
pub module_resolution: Option<String>,
pub resolve_package_json_exports: Option<bool>,
pub resolve_package_json_imports: Option<bool>,
pub module_suffixes: Option<Vec<String>>,
pub resolve_json_module: Option<bool>,
pub allow_arbitrary_extensions: Option<bool>,
pub allow_importing_ts_extensions: Option<bool>,
pub rewrite_relative_import_extensions: Option<bool>,
pub types_versions_compiler_version: Option<String>,
pub types: Option<Vec<String>>,
pub type_roots: Option<Vec<String>>,
pub jsx: Option<String>,
pub jsx_factory: Option<String>,
pub jsx_fragment_factory: Option<String>,
pub react_namespace: Option<String>,
pub lib: Option<Vec<String>>,
pub no_lib: Option<bool>,
pub no_types_and_symbols: Option<bool>,
pub base_url: Option<String>,
pub paths: Option<HashMap<String, Vec<String>, FxBuildHasher>>,
pub root_dir: Option<String>,
pub out_dir: Option<String>,
pub out_file: Option<String>,
pub declaration: Option<bool>,
pub declaration_dir: Option<String>,
pub source_map: Option<bool>,
pub declaration_map: Option<bool>,
pub ts_build_info_file: Option<String>,
pub incremental: Option<bool>,
pub strict: Option<bool>,
pub no_emit: Option<bool>,
pub no_resolve: Option<bool>,
pub no_emit_on_error: Option<bool>,
pub isolated_modules: Option<bool>,
pub custom_conditions: Option<Vec<String>>,
pub es_module_interop: Option<bool>,
pub allow_synthetic_default_imports: Option<bool>,
pub experimental_decorators: Option<bool>,
pub import_helpers: Option<bool>,
pub allow_js: Option<bool>,
pub check_js: Option<bool>,
pub skip_lib_check: Option<bool>,
pub always_strict: Option<bool>,
pub use_define_for_class_fields: Option<bool>,
pub no_implicit_any: Option<bool>,
pub no_implicit_returns: Option<bool>,
pub strict_null_checks: Option<bool>,
pub strict_function_types: Option<bool>,
pub strict_property_initialization: Option<bool>,
pub no_implicit_this: Option<bool>,
pub use_unknown_in_catch_variables: Option<bool>,
pub no_unchecked_indexed_access: Option<bool>,
pub strict_bind_call_apply: Option<bool>,
pub no_unused_locals: Option<bool>,
pub no_unused_parameters: Option<bool>,
pub allow_unreachable_code: Option<bool>,
pub no_unchecked_side_effect_imports: Option<bool>,
pub no_implicit_override: Option<bool>,
pub module_detection: Option<String>,
}Fields
target: Option<String>module: Option<String>module_resolution: Option<String>resolve_package_json_exports: Option<bool>Use the package.json ‘exports’ field when resolving package imports.
resolve_package_json_imports: Option<bool>Use the package.json ‘imports’ field when resolving imports.
module_suffixes: Option<Vec<String>>List of file name suffixes to search when resolving a module.
resolve_json_module: Option<bool>Enable importing .json files.
allow_arbitrary_extensions: Option<bool>Enable importing files with any extension, provided a declaration file is present.
allow_importing_ts_extensions: Option<bool>Allow imports to include TypeScript file extensions.
rewrite_relative_import_extensions: Option<bool>Rewrite ‘.ts’, ‘.tsx’, ‘.mts’, and ‘.cts’ file extensions in relative import paths.
types_versions_compiler_version: Option<String>types: Option<Vec<String>>type_roots: Option<Vec<String>>jsx: Option<String>jsx_factory: Option<String>jsx_fragment_factory: Option<String>react_namespace: Option<String>lib: Option<Vec<String>>no_lib: Option<bool>no_types_and_symbols: Option<bool>base_url: Option<String>paths: Option<HashMap<String, Vec<String>, FxBuildHasher>>root_dir: Option<String>out_dir: Option<String>out_file: Option<String>declaration: Option<bool>declaration_dir: Option<String>source_map: Option<bool>declaration_map: Option<bool>ts_build_info_file: Option<String>incremental: Option<bool>strict: Option<bool>no_emit: Option<bool>no_resolve: Option<bool>no_emit_on_error: Option<bool>isolated_modules: Option<bool>custom_conditions: Option<Vec<String>>Custom conditions for package.json exports resolution
es_module_interop: Option<bool>Emit additional JavaScript to ease support for importing CommonJS modules
allow_synthetic_default_imports: Option<bool>Allow ‘import x from y’ when a module doesn’t have a default export
experimental_decorators: Option<bool>Enable experimental support for legacy experimental decorators
import_helpers: Option<bool>Import emit helpers from tslib instead of inlining them per-file
allow_js: Option<bool>Allow JavaScript files to be a part of your program
check_js: Option<bool>Enable error reporting in type-checked JavaScript files
skip_lib_check: Option<bool>Skip type checking of declaration files (.d.ts)
always_strict: Option<bool>Parse in strict mode and emit “use strict” for each source file
use_define_for_class_fields: Option<bool>Use Object.defineProperty semantics for class fields when downleveling.
no_implicit_any: Option<bool>Raise error on expressions and declarations with an implied ‘any’ type
no_implicit_returns: Option<bool>Enable error reporting when a function doesn’t explicitly return in all code paths
strict_null_checks: Option<bool>Enable strict null checks
strict_function_types: Option<bool>Enable strict checking of function types
strict_property_initialization: Option<bool>Check for class properties that are declared but not set in the constructor
no_implicit_this: Option<bool>Raise error on ‘this’ expressions with an implied ‘any’ type
use_unknown_in_catch_variables: Option<bool>Default catch clause variables as ‘unknown’ instead of ‘any’
no_unchecked_indexed_access: Option<bool>Add ‘undefined’ to a type when accessed using an index
strict_bind_call_apply: Option<bool>Check that the arguments for ‘bind’, ‘call’, and ‘apply’ methods match the original function
no_unused_locals: Option<bool>Report errors on unused local variables
no_unused_parameters: Option<bool>Report errors on unused parameters
allow_unreachable_code: Option<bool>Do not report errors on unreachable code
no_unchecked_side_effect_imports: Option<bool>Check side-effect imports for module resolution errors
no_implicit_override: Option<bool>Require ‘override’ modifier on members that override base class members
module_detection: Option<String>Control what method is used to detect module-format JS files.